from data_scraper import *
def run_google_scraper(link):
    Id="VKDU2XN03IQ3VD7"
    response=scraper.run(link,id=Id)
    return response